@@ -220,7 +220,7 @@ class anim_text:
         self.obj.parent = parent
 
 
-    def animate(data, label, fix_place, if_str)
+    def animate(self, data, label, fix_place, if_str)
         if not(if_str):
             def update(self):
                 text = self.obj
